#
# Molleman-fishing.R,  7 Nov 21
#
# Data from:
# Unleashing the BEAST: a brief measure of human social information use

library("colorspace")
library("plyr")

par(las=1)
par(bty="l")
par(pch="+")
pal_col=rainbow(2)

calc_properties=function(lexp)
{
lexp$est_div5=((lexp$estimate %% 5) == 0)
lexp$est_div10=((lexp$estimate %% 10) == 0)
lexp$soc_div5=((lexp$socialobs %% 5) == 0)
lexp$secest_div5=((lexp$sec_est %% 5) == 0)
lexp$soc_shift=(lexp$sec_est-lexp$estimate)/(lexp$socialobs-lexp$estimate)
lexp$soc_isless=(lexp$socialobs<lexp$estimate)
lexp$soc_diff=(lexp$socialobs-lexp$estimate)

return(lexp)
}

exp1=read.csv("Molleman/data_waves123.txt", sep='\t', as.is=TRUE)

exp1_row=nrow(exp1)

cranes=count(exp1$cranes)
# t=cranes[order(cranes$freq, decreasing=TRUE), ]
# head(t)

plot(cranes)

# First wave experiment
lexpw1=data.frame(image=c(rep("ants", exp1_row), rep("bees", exp1_row), rep("flamingos", exp1_row),
		 		rep("cranes", exp1_row), rep("crickets", exp1_row)),
		 estimate=c(exp1$ants, exp1$bees, exp1$flamingos, exp1$cranes, exp1$crickets),
		 socialobs=c(exp1$obsSocialInfo1, exp1$obsSocialInfo2, exp1$obsSocialInfo3,
			  	exp1$obsSocialInfo4, exp1$obsSocialInfo5),
		 sec_est=c(exp1$ants_revised, exp1$bees_revised, exp1$flamingos_revised,
			   exp1$cranes_revised, exp1$crickets_revised))

# Second wave
lexpw2=data.frame(image=c(rep("ants", exp1_row), rep("bees", exp1_row), rep("flamingos", exp1_row),
		 		rep("cranes", exp1_row), rep("crickets", exp1_row)),
		 estimate=c(exp1$ants_R, exp1$bees_R, exp1$flamingos_R, exp1$cranes_R, exp1$crickets_R),
		 socialobs=c(exp1$obsSocialInfo1_R, exp1$obsSocialInfo2_R, exp1$obsSocialInfo3_R,
			  	exp1$obsSocialInfo4_R, exp1$obsSocialInfo5_R),
		 sec_est=c(exp1$ants_revised_R, exp1$bees_revised_R, exp1$flamingos_revised_R,
			   exp1$cranes_revised_R, exp1$crickets_revised_R))

# Third wave
lexpw3=data.frame(image=c(rep("ants", exp1_row), rep("bees", exp1_row), rep("flamingos", exp1_row),
		 		rep("cranes", exp1_row), rep("crickets", exp1_row)),
		 estimate=c(exp1$ants_RR, exp1$bees_RR, exp1$flamingos_RR, exp1$cranes_RR, exp1$crickets_RR),
		 socialobs=c(exp1$obsSocialInfo1_RR, exp1$obsSocialInfo2_RR, exp1$obsSocialInfo3_RR,
			  	exp1$obsSocialInfo4_RR, exp1$obsSocialInfo5_RR),
		 sec_est=c(exp1$ants_revised_RR, exp1$bees_revised_RR, exp1$flamingos_revised_RR,
			   exp1$cranes_revised_RR, exp1$crickets_revised_RR))

lexpw1=calc_properties(lexpw1)
lexpw2=calc_properties(lexpw2)
lexpw3=calc_properties(lexpw3)

# > mean(lexpw1$soc_shift)
# [1] 0.3439367
# > median(lexpw1$soc_shift)
# [1] 0.3333333

ss_cnt=count(lexpw1$soc_shift)

plot(ss_cnt$x*100, ss_cnt$freq, log="y", col=pal_col[2],
	xlab="Change in first estimate towards social estimate (percent)", ylab="Estimates")

# Fit a loess line
ss_pos_cnt=subset(ss_cnt, x >=0)
loess_mod=loess(log(freq) ~ x, data=ss_pos_cnt, span=0.3)
loess_pred=predict(loess_mod)
lines(100*ss_pos_cnt$x, exp(loess_pred), col=pal_col[1])

# dev.copy(dev=png, file="molleman-social-est.png")
# dev.off()

# Try and fit various regression models

# soc1_mod=glm(soc_shift ~ log(estimate)+log(socialobs)+est_div5+soc_div5, data=lexpw1,
soc1_mod=glm(soc_shift ~ log(estimate)+log(socialobs)+est_div5+soc_isless, data=lexpw1,
						subset=(soc_shift >= 0))
# soc1_mod=glm(soc_shift ~ log(estimate)+log(socialobs)+est_div5+soc_isless, data=lexpw1,
soc1_mod=glm(soc_shift ~ log(estimate)+est_div5+soc_diff, data=lexpw1,
						subset=(soc_shift >= 0) & (soc_shift <= 1))
soc1_mod=glm(soc_shift ~ est_div5, data=lexpw1,
						subset=(soc_shift >= 0) & (soc_shift <= 1))
summary(soc1_mod)

# What impact does divide-by-5 estimate have in later reruns?
soc2_mod=glm(soc_shift ~ est_div5, data=lexpw2,
                                                subset=(soc_shift >= 0) & (soc_shift <= 1))
summary(soc2_mod)

soc3_mod=glm(soc_shift ~ est_div5, data=lexpw3,
                                                subset=(soc_shift >= 0) & (soc_shift <= 1))
summary(soc3_mod)

# Model the second estimate, based on the first+social
act_mod=glm(log(sec_est) ~ log(estimate)+log(socialobs), data=lexpw1,
                                                subset=(soc_shift >= 0) & (soc_shift <= 1))
summary(act_mod)


